stowaway.util


key-joinclj

(key-join & vs)

Returns the given params (strings for keywords) joined into a keyword.

Returns the given params (strings for keywords) joined into a keyword.
sourceraw docstring

pp->clj

(pp-> v m)
source

pp->>clj

(pp->> m v)
source

qualify-keycljmultimethod

source

qualify-keysclj

(qualify-keys m ns-key & {:keys [ignore]})

Creates fully-qualified entity attributes by applying the :model-type from the meta data to the keys of the map.

Creates fully-qualified entity attributes by applying
the :model-type from the meta data to the keys of the map.
sourceraw docstring

type-dispatchclj

(type-dispatch x & _)
source

unqualify-keysclj

(unqualify-keys m)

Replaces qualified keys with the simple values

Replaces qualified keys with the simple values
sourceraw docstring

update-in-ifclj

(update-in-if m k f)
source

cljdoc builds & hosts documentation for Clojure/Script libraries